// -*- mode: C++; c-file-style: "Stroustrup" -*-
//
// This file is part of krot,
// a program for the simulation, assignment and fit of HRLIF spectra.
//
// Copyright (C) 1998 Jochen Kpper
//
// This program is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// this program; see the file License. if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 , USA
//
// If you use this program for your scientific work, please cite it according to
// the file CITATION that comes with the package.
//
// $Id: scrollbar64.cc,v 1.3 1998/10/09 14:49:20 jochen Exp $


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#if ( SIZEOF_INT < 8 )
#warning Using our own int64_t replacement for QScrollBar


#include "krot.h"
#include "scrollbar64.h"



ScrollBar64::ScrollBar64( QWidget *parent, const char *name )
    : QWidget( parent, name ),
      qscrollbar( new QScrollBar( this ) ),
      div( 1 ), max( 0 ), min( 0 ), shift( 0 )
{
    KROT_LAUNCH( "Launching ScrollBar64 constructor" );
    init();
    doIt();
    return;
}



ScrollBar64::ScrollBar64( Orientation orient, QWidget *parent, const char *name )
    : QWidget( parent, name ),
      qscrollbar( new QScrollBar( orient, this ) ),
      div( 1 ), line( 1 ), max( 0 ), min( 0 ), shift( 0 )
{
    KROT_LAUNCH( "Launching ScrollBar64 constructor" );
    init();
    doIt();
    return;
}



ScrollBar64::ScrollBar64( int64_t minValue, int64_t maxValue, int64_t lineStep,
		      int64_t pageStep, int64_t value, Orientation orient,
		      QWidget *parent=0, const char *name=0 )
    : QWidget( parent, name ),
      qscrollbar( new QScrollBar( orient, this ) ),
      div( 1 ), line( lineStep ), max( maxValue ), min( minValue ),
      page( pageStep ), shift( 0 ), val( value )
{
    KROT_LAUNCH( "Launching ScrollBar64 constructor" );
    init();
    doIt();
    return;
}



void ScrollBar64::slotSliderMoved( int val )
{
    KROT_LAUNCH_VERBOSE( "Launching ScrollBar64::slotSliderMoved" );
    emit sliderMoved( div * val - shift );
    return;
}



void ScrollBar64::slotValueChanged( int val )
{
    KROT_LAUNCH_VERBOSE( "Launching ScrollBar64::slotValueChanged" );
    emit valueChanged( div * val - shift );
    return;
}



#endif // SIZEOF_INT < 8
